@@ -14,9 +14,11 @@ requires 'reverse';
 requires 'sort';
 requires 'tail';
 
+our $VERSION = '0.05'; # VERSION
+
 sub reduce {
     my $self = CORE::shift;
-    my $code = bbbl'gm::chkcode CORE::shift;
+    my $code = bbblgm::chkcode CORE::shift;
     my $a    = [0 .. $#{$self}];
     my $acc  = $a->head;
     $a->tail->map(sub { $acc = $code->($acc, $_) });
@@ -25,7 +27,7 @@ sub reduce {
 
 sub zip {
     my $self  = CORE::shift;
-    my $other = bbbl'gm::chkarray CORE::shift;
+    my $other = bbblgm::chkarray CORE::shift;
     my $this  = $self->length < $other->length ? $other : $self;
     my $a     = [0 .. $#{$this}];
     return $this->keys->map(sub { [$self->get($_), $other->get($_)] });
