@@ -4,9 +4,11 @@ use Bubblegum::Role 'with';
 
 with 'Bubblegum::Object::Role::Defined';
 
+our $VERSION = '0.05'; # VERSION
+
 sub do {
     my $self = CORE::shift;
-    my $code = bbbl'gm::chkcode CORE::shift;
+    my $code = bbblgm::chkcode CORE::shift;
 
     local $_ = $self;
     return $code->($self);
