@@ -1,10 +1,12 @@
 package Bubblegum::Wrapper::Dumper;
 
-use Bubblegum;
+use Bubblegum::Class;
 use Data::Dumper ();
 
 extends 'Bubblegum::Object::Instance';
 
+our $VERSION = '0.05'; # VERSION
+
 sub decode {
     my $self = shift;
     return eval $self->data;
