@@ -1,10 +1,12 @@
 package Bubblegum::Wrapper::Yaml;
 
-use Bubblegum;
+use Bubblegum::Class;
 use YAML::Tiny ();
 
 extends 'Bubblegum::Object::Instance';
 
+our $VERSION = '0.05'; # VERSION
+
 sub decode {
     my $self = shift;
     my $yaml = YAML::Tiny->new;
